summaryrefslogtreecommitdiff
path: root/qadevOOo/tests
diff options
context:
space:
mode:
authorJulien Nabet <serval2412@yahoo.fr>2015-02-26 23:02:35 +0100
committerJulien Nabet <serval2412@yahoo.fr>2015-02-26 23:03:14 +0100
commitca7f62c8262662c8f58a3fa3b298623f25b55eaa (patch)
treefa094c98fa77f90887457535684182abfe773619 /qadevOOo/tests
parent46ce83541b2670e72f1281f8d3a7df5af9c4aed2 (diff)
Typos
Change-Id: Ic03fb2ee6470eac6034be13908dd9ec92cf175b6
Diffstat (limited to 'qadevOOo/tests')
-rw-r--r--qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java12
-rw-r--r--qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java2
-rw-r--r--qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java2
3 files changed, 8 insertions, 8 deletions
diff --git a/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java b/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java
index 55da8c133513..1a6a583819a8 100644
--- a/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java
+++ b/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java
@@ -88,7 +88,7 @@ public class _XEnhancedMouseClickBroadcaster extends MultiMethodTest {
Point point = window.getLocationOnScreen();
Rectangle rect = window.getBounds();
- log.println("klick mouse button...");
+ log.println("click mouse button...");
try {
Robot rob = new Robot();
int x = point.X + (rect.Width / 2)+50;
diff --git a/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java b/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java
index 243fdc0dc7c5..3935c9044196 100644
--- a/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java
+++ b/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java
@@ -167,7 +167,7 @@ public class _XContextMenuInterception extends MultiMethodTest {
point = window.getLocationOnScreen();
Rectangle rect = window.getBounds();
- log.println("klick mouse button...");
+ log.println("click mouse button...");
try {
Robot rob = new Robot();
int x = point.X + (rect.Width / 2);
diff --git a/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java b/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java
index 43bffcf83360..58ccffa3d2df 100644
--- a/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java
+++ b/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java
@@ -174,7 +174,7 @@ public class _XUserInputInterception extends MultiMethodTest {
}
/**
* This test adds two different mouse klick listener to the object. <p>
*
* Has <b> OK </b> if no exception is thrown.
*/
@@ -194,7 +194,7 @@ public class _XUserInputInterception extends MultiMethodTest {
/**
* The test requires <CODE>addMouseClickHandler()</CODE> which adds two key listener.
* Then one of them will be removed. In a second thread a mouse klick event is released
* by the <CODE>robot</CODE> class.<p>
* Has <b> OK </b> status if only one of the listener are triggered. <p>
* The following method tests are to be completed successfully before :
@@ -452,10 +452,10 @@ public class _XUserInputInterception extends MultiMethodTest {
}
}
/**
- * This method cklicks into the middel of a document. It uses Accessibility
+ * This method clicks into the middle of a document. It uses Accessibility
* to get the document and query for its position and its range to calculate
* the middle. This values was used for <CODE>Robot</CODE> Class. This
* Robot class is able to move the mouse and to cklick a mouse button
* @see java.awt.Robot
*/
private void clickIntoDoc(){
@@ -483,7 +483,7 @@ public class _XUserInputInterception extends MultiMethodTest {
Robot rob = new Robot();
int x = point.X + (rect.Width / 2);
int y = point.Y + (rect.Height / 2);
- log.println("try to klick into the middle of the document");
+ log.println("try to click into the middle of the document");
rob.mouseMove(x, y);
rob.mousePress(InputEvent.BUTTON1_MASK);
rob.mouseRelease(InputEvent.BUTTON1_MASK);
@@ -519,7 +519,7 @@ public class _XUserInputInterception extends MultiMethodTest {
*/
private interface EventTriggerType{
/** klick the mouse into the scroll bar*/
int MOUSE_KLICK_INTO_DOC = 1;
/** write some text into a spread sheet*/
@@ -174,7 +174,7 @@ public class _XUserInputInterception extends MultiMethodTest {
}
/**
- * This test adds two different mouse klick listener to the object. <p>
+ * This test adds two different mouse click listener to the object. <p>
*
* Has <b> OK </b> if no exception is thrown.
@@ -194,7 +194,7 @@ public class _XUserInputInterception extends MultiMethodTest {
/**
* The test requires <CODE>addMouseClickHandler()</CODE> which adds two key listener.
- * Then one of them will be removed. In a second thread a mouse klick event is released
+ * Then one of them will be removed. In a second thread a mouse click event is released
* by the <CODE>robot</CODE> class.<p>
* Has <b> OK </b> status if only one of the listener are triggered. <p>
@@ -452,10 +452,10 @@ public class _XUserInputInterception extends MultiMethodTest {
* to get the document and query for its position and its range to calculate
* the middle. This values was used for <CODE>Robot</CODE> Class. This
- * Robot class is able to move the mouse and to cklick a mouse button
+ * Robot class is able to move the mouse and to click a mouse button
* @see java.awt.Robot
*/
@@ -519,7 +519,7 @@ public class _XUserInputInterception extends MultiMethodTest {
*/
private interface EventTriggerType{
- /** klick the mouse into the scroll bar*/
+ /** click the mouse into the scroll bar*/
int MOUSE_KLICK_INTO_DOC = 1;
/** write some text into a spread sheet*/